==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/SharepointdocumentlocationCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Sharepointdocumentlocation;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SharepointdocumentlocationRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class SharepointdocumentlocationCollectionRequest extends CollectionPageEntityRequest<Sharepointdocumentlocation, SharepointdocumentlocationRequest>{

    protected ContextPath contextPath;

    public SharepointdocumentlocationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Sharepointdocumentlocation.class, cp -> new SharepointdocumentlocationRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public PrincipalobjectattributeaccessCollectionRequest sharepointdocumentlocation_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("sharepointdocumentlocation_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest sharepointdocumentlocation_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("sharepointdocumentlocation_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SharepointdocumentlocationCollectionRequest sharepointdocumentlocation_parent_sharepointdocumentlocation() {
        return new SharepointdocumentlocationCollectionRequest(contextPath.addSegment("sharepointdocumentlocation_parent_sharepointdocumentlocation"), Optional.empty());
    }

    public SharepointdocumentlocationRequest sharepointdocumentlocation_parent_sharepointdocumentlocation(String sharepointdocumentlocationid) {
        return new SharepointdocumentlocationRequest(contextPath.addSegment("sharepointdocumentlocation_parent_sharepointdocumentlocation").addKeys(new NameValue(sharepointdocumentlocationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest sharePointDocumentLocation_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest sharePointDocumentLocation_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest sharePointDocumentLocation_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest sharePointDocumentLocation_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest sharePointDocumentLocation_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest sharePointDocumentLocation_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("SharePointDocumentLocation_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest sharePointDocumentLocation_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest sharePointDocumentLocation_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("SharePointDocumentLocation_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest sharePointDocumentLocation_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest sharePointDocumentLocation_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("SharePointDocumentLocation_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/SharepointdocumentlocationCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Sharepointdocumentlocation;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SharepointdocumentlocationRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class SharepointdocumentlocationCollectionRequest extends CollectionPageEntityRequest<Sharepointdocumentlocation, SharepointdocumentlocationRequest>{

    protected ContextPath contextPath;

    public SharepointdocumentlocationCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Sharepointdocumentlocation.class, cp -> new SharepointdocumentlocationRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public PrincipalobjectattributeaccessCollectionRequest sharepointdocumentlocation_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("sharepointdocumentlocation_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest sharepointdocumentlocation_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("sharepointdocumentlocation_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SharepointdocumentlocationCollectionRequest sharepointdocumentlocation_parent_sharepointdocumentlocation() {
        return new SharepointdocumentlocationCollectionRequest(contextPath.addSegment("sharepointdocumentlocation_parent_sharepointdocumentlocation"), Optional.empty());
    }

    public SharepointdocumentlocationRequest sharepointdocumentlocation_parent_sharepointdocumentlocation(String sharepointdocumentlocationid) {
        return new SharepointdocumentlocationRequest(contextPath.addSegment("sharepointdocumentlocation_parent_sharepointdocumentlocation").addKeys(new NameValue(sharepointdocumentlocationid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest sharePointDocumentLocation_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest sharePointDocumentLocation_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest sharePointDocumentLocation_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest sharePointDocumentLocation_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("SharePointDocumentLocation_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest sharePointDocumentLocation_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest sharePointDocumentLocation_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("SharePointDocumentLocation_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest sharePointDocumentLocation_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest sharePointDocumentLocation_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("SharePointDocumentLocation_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest sharePointDocumentLocation_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("SharePointDocumentLocation_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest sharePointDocumentLocation_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("SharePointDocumentLocation_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

}
